@@ -31,13 +31,14 @@
 #include <gtk/gtk.h>
 
 #include <libgnome/gnome-macros.h>
+#include <libgnome/gnome-i18n.h>
 #include "gnome-desktop-i18n.h"
 
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomeui/gnome-icon-entry.h>
 
-#include "gnome-desktop-item.h"
-#include "gnome-ditem-edit.h"
+#include <libgnome/gnome-desktop-item.h>
+#include <libgnomeui/gnome-ditem-edit.h>
 
 struct _GnomeDItemEditPrivate {
 	/* we keep a ditem around, since we can never have absolutely
@@ -382,6 +383,8 @@ make_easy_page (GnomeDItemEdit *dee)
 	dee->_priv->exec_label = label;
 
 	entry = gnome_file_entry_new ("command", _("Browse"));
+	g_object_set (G_OBJECT (entry), "use-filechooser", TRUE, NULL);
+
 	gtk_label_set_mnemonic_widget (GTK_LABEL(label), gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (entry)));
 	table_attach_entry (GTK_TABLE (table), entry, 1, 2, 3, 4);
  
